==> uhub-0.1.3-2147-src.tar.gz: uhub-0.1.3-2147/src/hubevent.c <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "uhub.h"

/* Send MOTD, do logging etc */
void on_login_success(struct hub_info* hub, struct user* u, int authenticated)
{
	/* Logging */
	
	const char* credentials_string[] = { "guest", "link", "user", "registered user", "operator", "admin" };
	
	const char* addr = net_get_peer_address(u->sd);
	hub_log(log_user, "Login OK    %s \"%s\" [%s] (%s) %s", u->cid, u->nick, addr, credentials_string[u->credentials], u->user_agent);
	
	hub_send_motd(hub, u);
	
	send_user_list(hub, u);
	
	u->state = state_normal;
	route_to_user(u, u->info);
	
}

void on_login_failure(struct hub_info* hub, struct user* u, struct adc_message* cmd, const char* message)
{
	const char* addr = net_get_peer_address(u->sd);
	hub_log(log_user, "Login FAIL  %s \"%s\" [%s] (%s) %s", u->cid, u->nick, addr, message, u->user_agent);
	
	if (cmd)
	{
		route_to_user(u, cmd);
		user_disconnect(u, quit_logon_error);
	}
}


void on_logout_user(struct hub_info* hub, struct user* user)
{
	const char* reason = "";
	
	if (user->info && user->credentials >= cred_user)
	{
		send_quit_message(hub, user);
	}
	
	switch (user->quit_reason)
	{
		case quit_disconnected:     reason = "disonnected";    break;
		case quit_kicked:           reason = "kicked";         break;
		case quit_banned:           reason = "banned";         break;
		case quit_timeout:          reason = "timeout";        break;
		case quit_send_queue:       reason = "send queue";     break;
		case quit_memory_error:     reason = "out of memory";  break;
		case quit_socket_error:     reason = "socket error";   break;
		case quit_protocol_error:   reason = "protocol error"; break;
		case quit_logon_error:      reason = "login error";    break;
		default:
		                            reason = "unknown error";  break;
	}
	
	hub_log(log_user, "Logout      %s \"%s\" (%s)", user->cid, user->nick, reason);
}

==> uhub-0.1.4-2301-src.tar.gz: uhub-0.1.4-2301/src/hubevent.c <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#include "uhub.h"

/* Send MOTD, do logging etc */
void on_login_success(struct hub_info* hub, struct user* u, int authenticated)
{
	/* Logging */
	const char* credentials_string[] = { "!none!", "link", "guest", "user", "operator", "admin" };
	u->credentials = authenticated;
	
	const char* addr = net_get_peer_address(u->sd);
	hub_log(log_user, "Login OK    %s \"%s\" [%s] (%s) %s", u->cid, u->nick, addr, credentials_string[u->credentials], u->user_agent);
	
	hub_send_motd(hub, u);
	
	send_user_list(hub, u);
	
	u->state = state_normal;
	route_to_user(u, u->info);
	
	/* reset to idle timeout */
	struct timeval timeout = { TIMEOUT_IDLE, 0 };
	event_add(&u->ev_read, &timeout);
}

void on_login_failure(struct hub_info* hub, struct user* u, struct adc_message* cmd, const char* message)
{
	const char* addr = net_get_peer_address(u->sd);
	hub_log(log_user, "Login FAIL  %s \"%s\" [%s] (%s) %s", u->cid, u->nick, addr, message, u->user_agent);
	
	if (cmd)
	{
		route_to_user(u, cmd);
		user_disconnect(u, quit_logon_error);
	}
}


void on_logout_user(struct hub_info* hub, struct user* user)
{
	(void) hub;
	const char* reason = "";
	
	switch (user->quit_reason)
	{
		case quit_disconnected:     reason = "disonnected";    break;
		case quit_kicked:           reason = "kicked";         break;
		case quit_banned:           reason = "banned";         break;
		case quit_timeout:          reason = "timeout";        break;
		case quit_send_queue:       reason = "send queue";     break;
		case quit_memory_error:     reason = "out of memory";  break;
		case quit_socket_error:     reason = "socket error";   break;
		case quit_protocol_error:   reason = "protocol error"; break;
		case quit_logon_error:      reason = "login error";    break;
		default:                    reason = "unknown error";  break;
	}
	
	hub_log(log_user, "Logout      %s \"%s\" (%s)", user->cid, user->nick, reason);
}
